@@ -28,3 +28,6 @@ define("SYNC_PROVISION_RWSTATUS_OK", 1);
 define("SYNC_PROVISION_RWSTATUS_PENDING", 2);
 define("SYNC_PROVISION_RWSTATUS_REQUESTED", 4);
 define("SYNC_PROVISION_RWSTATUS_WIPED", 8);
+define("SYNC_PROVISION_RWSTATUS_PENDING_ACCOUNT_ONLY", 16);
+define("SYNC_PROVISION_RWSTATUS_REQUESTED_ACCOUNT_ONLY", 32);
+define("SYNC_PROVISION_RWSTATUS_WIPED_ACCOUNT_ONLY", 64);
