@@ -359,17 +359,17 @@ Zarafa.plugins.smime.dialogs.ChangePassphrasePanel = Ext.extend(Ext.Panel, {
 	 */
 	changePassphrasePanel: function()
 	{
-			container.getRequest().singleRequest(
-				'pluginsmimemodule',
-				'changepassphrase',
-				{
-					'passphrase': this.old_passphrase.getValue(),
-					'new_passphrase': this.new_passphrase.getValue()
-				},
-				new Zarafa.plugins.smime.data.SmimeResponseHandler({
-					successCallback : this.onChangePassphraseRequest.createDelegate(this)
-				})
-			);
+		container.getRequest().singleRequest(
+			'pluginsmimemodule',
+			'changepassphrase',
+			{
+				'passphrase': this.old_passphrase.getValue(),
+				'new_passphrase': this.new_passphrase.getValue()
+			},
+			new Zarafa.plugins.smime.data.SmimeResponseHandler({
+				successCallback : this.onChangePassphraseRequest.createDelegate(this)
+			})
+		);
 	},
 
 	/**
@@ -1042,17 +1042,17 @@ Zarafa.plugins.smime.settings.PublickeyGrid = Ext.extend(Ext.grid.GridPanel, {
 	{
 		var selectionModel = this.getSelectionModel();
 		var certificate = selectionModel.getSelected();
-		if(Ext.isDefined(certificate)) {
-			// TODO: use ExtJS form?
-			
-			var text = "Email: " + certificate.get('email') + "</br>" +
-				"Serial: " + certificate.get('serial') + "</br>" +
-				"Issued by: " + certificate.get('issued_by') + "</br>" +
-				"Issued to: " + certificate.get('issued_to') + "</br>" +
-				"SHA1 Fingerprint: " + certificate.get('fingerprint_sha1') + "</br>" +
-				"MD5 Fingerprint: " + certificate.get('fingerprint_md5') + "</br>";
-			Ext.Msg.alert(_('Certificate details'), text);
-		}
+		if (!Ext.isDefined(certificate))
+			return;
+		// TODO: use ExtJS form?
+		
+		var text = "Email: " + certificate.get('email') + "</br>" +
+			"Serial: " + certificate.get('serial') + "</br>" +
+			"Issued by: " + certificate.get('issued_by') + "</br>" +
+			"Issued to: " + certificate.get('issued_to') + "</br>" +
+			"SHA1 Fingerprint: " + certificate.get('fingerprint_sha1') + "</br>" +
+			"MD5 Fingerprint: " + certificate.get('fingerprint_md5') + "</br>";
+		Ext.Msg.alert(_('Certificate details'), text);
 	}
 
 });
@@ -1569,12 +1569,12 @@ Zarafa.plugins.smime.settings.SettingsSmimeWidget = Ext.extend(Zarafa.settings.u
 		if(index === -1) {
 			this.certificateField.disable();
 			this.setCertificateButtonLabel(this.defaultButtonLabel);
-		} else {
-			this.certificateField.enable();
-			this.record = this.store.getAt(index);
-			// TODO: add validity message
-			this.setCertificateButtonLabel(_('You have a valid certificate corresponding to your account'));
+			return;
 		}
+		this.certificateField.enable();
+		this.record = this.store.getAt(index);
+		// TODO: add validity message
+		this.setCertificateButtonLabel(_('You have a valid certificate corresponding to your account'));
 	},
 
 	/**
@@ -1840,7 +1840,7 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 	},
 
 	/**
-	 * Create button which sets the MessageClass to IPM.Note.SMIME.MultiPartSigned
+	 * Create button which sets the MessageClass to IPM.Note.deferSMIME.MultiPartSigned
 	 * when creating an email.
 	 * If certificate is unlocked we can display the Sign button, else a blank label
 	 *
@@ -1867,7 +1867,7 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 	},
 
 	/**
-	 * Create button which sets the MessageClass to IPM.Note.SMIME
+	 * Create button which sets the MessageClass to IPM.Note.deferSMIME
 	 * when creating an email in context.mail.mailcreatecontentpanel.toolbar.option
 	 *
 	 * @return {Object} creates a button for encrypting an email
@@ -1904,23 +1904,23 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 		var dialog = this.getRespectiveDialog(button);
 		var record = dialog.record;
 		switch(record.get('message_class')) {
-			case 'IPM.Note.SMIME':
-				if (button.iconCls === 'icon_smime_encrypt') {
-					button.setIconClass('icon_smime_encrypt_selected');
-				}
-				break;
-			case 'IPM.Note.SMIME.MultipartSigned':
-				if (button.iconCls === 'icon_smime_sign') {
-					button.setIconClass('icon_smime_sign_selected');
-				}
-				break;
-			case 'IPM.Note.SMIME.SignedEncrypt':
-				if (button.iconCls === 'icon_smime_sign') {
-					button.setIconClass('icon_smime_sign_selected');
-				} else {
-					button.setIconClass('icon_smime_encrypt_selected');
-				}
-				break;
+		case 'IPM.Note.deferSMIME':
+			if (button.iconCls === 'icon_smime_encrypt') {
+				button.setIconClass('icon_smime_encrypt_selected');
+			}
+			break;
+		case 'IPM.Note.deferSMIME.MultipartSigned':
+			if (button.iconCls === 'icon_smime_sign') {
+				button.setIconClass('icon_smime_sign_selected');
+			}
+			break;
+		case 'IPM.Note.deferSMIME.SignedEncrypt':
+			if (button.iconCls === 'icon_smime_sign') {
+				button.setIconClass('icon_smime_sign_selected');
+			} else {
+				button.setIconClass('icon_smime_encrypt_selected');
+			}
+			break;
 		}
 	},
 
@@ -1932,29 +1932,29 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 	onSmimeButton: function(button)
 	{
 		var smimeInfo = button.record.get('smime');
-		if(button.record.isOpened() && smimeInfo) {
-			switch(smimeInfo.type) {
-				case 'encrypted':
-					if (smimeInfo.success !== Zarafa.plugins.smime.SMIME_STATUS_GOOD) {
-						var user = container.getUser();
-						container.getRequest().singleRequest(
-							'pluginsmimemodule',
-							'certificate',
-							{
-								'user' : user.getSMTPAddress()
-							},
-							new Zarafa.plugins.smime.data.SmimeResponseHandler({
-								successCallback : this.onCertificateCallback.createDelegate(button.record)
-							})
-						);
-					}
-					break;
-				case 'signed':
-				case 'encryptsigned':
-					container.getNotifier().notify(Zarafa.plugins.smime.SmimeText.getPopupStatus(smimeInfo.success),
-							_('What\'s going on with my email?'), Zarafa.plugins.smime.SmimeText.getPopupText(smimeInfo.info));
-					break;
-			}
+		if (!button.record.isOpened() || !smimeInfo)
+			return;
+		switch (smimeInfo.type) {
+		case 'encrypted':
+			if (smimeInfo.success === Zarafa.plugins.smime.SMIME_STATUS_GOOD)
+				break;
+			var user = container.getUser();
+			container.getRequest().singleRequest(
+				'pluginsmimemodule',
+				'certificate',
+				{
+					'user' : user.getSMTPAddress()
+				},
+				new Zarafa.plugins.smime.data.SmimeResponseHandler({
+					successCallback : this.onCertificateCallback.createDelegate(button.record)
+				})
+			);
+			break;
+		case 'signed':
+		case 'encryptsigned':
+			container.getNotifier().notify(Zarafa.plugins.smime.SmimeText.getPopupStatus(smimeInfo.success),
+					_('What\'s going on with my email?'), Zarafa.plugins.smime.SmimeText.getPopupText(smimeInfo.info));
+			break;
 		}
 	},
 
@@ -1981,36 +1981,36 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 
 		// retrieve smime json object
 		var smimeInfo = record.get('smime');
-		if(record.isOpened() && smimeInfo) {
-			var sender = record.getSender();
+		if (!record.isOpened() || !smimeInfo)
+			return;
+		var sender = record.getSender();
 
-			// FIXME: refactor success, to status since that's probably a better description of the variable
-			smimeInfoBox.addClass(Zarafa.plugins.smime.SmimeText.getStatusMessageClass(smimeInfo.success));
-			var message = Zarafa.plugins.smime.SmimeText.getMessageInfo(smimeInfo.info);
-			var isDecryptedSuccessfully = (smimeInfo.info === Zarafa.plugins.smime.SMIME_DECRYPT_SUCCESS);
-			switch(smimeInfo.type) {
-				case 'encrypted':
-					// Empty smimeInfoBox
-					if( smimeInfo.success === Zarafa.plugins.smime.SMIME_STATUS_BAD) {
-						smimeInfoBox.update('<div class="icon_smime_encr_content"></div> ' + message);
-					} else {
-						var smimeInfoIcon = isDecryptedSuccessfully ? 'icon_smime_decr_content' : 'icon_smime_encr_content';
-						smimeInfoBox.update(String.format(' {0} &lt{1}&gt <div class="{2}"></div> {3}', sender.get('display_name'), sender.get('smtp_address'), smimeInfoIcon, message));
-						// Force the Attachmentlinks component to update, to view the attachments
-						this.ownerCt.findByType('zarafa.attachmentlinks')[0].update(record, true);
-					}
-					break;
-				case 'signed':
-					smimeInfoBox.update(String.format('{0} &lt{1}&gt <div class="icon_smime_sign_content"></div> {2}', sender.get('display_name'), sender.get('smtp_address'), message));
-					break;
-				case 'encryptsigned':
-					smimeInfoBox.update(String.format('{0} &lt{1}&gt <div class="icon_smime_sign_content"></div> <div class="icon_smime_decr_content"></div> {2}', sender.get('display_name'), sender.get('smtp_address'), message));
-					if(smimeInfo.success !== Zarafa.plugins.smime.SMIME_STATUS_BAD) {
-						// Force the Attachmentlinks component to update, to view the attachments
-						this.ownerCt.findByType('zarafa.attachmentlinks')[0].update(record, true);
-					}
-					break;
+		// FIXME: refactor success, to status since that's probably a better description of the variable
+		smimeInfoBox.addClass(Zarafa.plugins.smime.SmimeText.getStatusMessageClass(smimeInfo.success));
+		var message = Zarafa.plugins.smime.SmimeText.getMessageInfo(smimeInfo.info);
+		var isDecryptedSuccessfully = (smimeInfo.info === Zarafa.plugins.smime.SMIME_DECRYPT_SUCCESS);
+		switch (smimeInfo.type) {
+		case 'encrypted':
+			// Empty smimeInfoBox
+			if (smimeInfo.success === Zarafa.plugins.smime.SMIME_STATUS_BAD) {
+				smimeInfoBox.update('<div class="icon_smime_encr_content"></div> ' + message);
+				break;
 			}
+			var smimeInfoIcon = isDecryptedSuccessfully ? 'icon_smime_decr_content' : 'icon_smime_encr_content';
+			smimeInfoBox.update(String.format(' {0} &lt{1}&gt <div class="{2}"></div> {3}', sender.get('display_name'), sender.get('smtp_address'), smimeInfoIcon, message));
+			// Force the Attachmentlinks component to update, to view the attachments
+			this.ownerCt.findByType('zarafa.attachmentlinks')[0].update(record, true);
+			break;
+		case 'signed':
+			smimeInfoBox.update(String.format('{0} &lt{1}&gt <div class="icon_smime_sign_content"></div> {2}', sender.get('display_name'), sender.get('smtp_address'), message));
+			break;
+		case 'encryptsigned':
+			smimeInfoBox.update(String.format('{0} &lt{1}&gt <div class="icon_smime_sign_content"></div> <div class="icon_smime_decr_content"></div> {2}', sender.get('display_name'), sender.get('smtp_address'), message));
+			if (smimeInfo.success !== Zarafa.plugins.smime.SMIME_STATUS_BAD) {
+				// Force the Attachmentlinks component to update, to view the attachments
+				this.ownerCt.findByType('zarafa.attachmentlinks')[0].update(record, true);
+			}
+			break;
 		}
 	},
 
@@ -2062,45 +2062,45 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 	{
 		var dialog = this.getRespectiveDialog(button);
 		var record = dialog.record;
-		if(record) {
-			switch(record.get('message_class')) {
-				// Sign and Encrypt
-				case 'IPM.Note.SMIME.MultipartSigned':
-					record.set('message_class', 'IPM.Note.SMIME.SignedEncrypt');
-					button.setIconClass('icon_smime_encrypt_selected');
+		if (!record)
+			return;
+		switch (record.get('message_class')) {
+		// Sign and Encrypt
+		case 'IPM.Note.deferSMIME.MultipartSigned':
+			record.set('message_class', 'IPM.Note.deferSMIME.SignedEncrypt');
+			button.setIconClass('icon_smime_encrypt_selected');
 
-					// Add event to check if all recipients have a public key
-					dialog.on('beforesendrecord', this.onBeforeSendRecord ,this);
-					break;
-				// We want to encrypt
-				case 'IPM.Note':
-					button.setIconClass('icon_smime_encrypt_selected');
-					record.set('message_class', 'IPM.Note.SMIME');
+			// Add event to check if all recipients have a public key
+			dialog.on('beforesendrecord', this.onBeforeSendRecord ,this);
+			break;
+		// We want to encrypt
+		case 'IPM.Note':
+			button.setIconClass('icon_smime_encrypt_selected');
+			record.set('message_class', 'IPM.Note.deferSMIME');
 
-					// Add event to check if all recipients have a public key
-					dialog.on('beforesendrecord', this.onBeforeSendRecord ,this);
-					break;
-				// Unselecting encrypt functionality
-				case 'IPM.Note.SMIME':
-				case 'IPM.Note.SMIME.SignedEncrypt':
-					if (record.get('message_class') === 'IPM.Note.SMIME.SignedEncrypt') {
-						record.set('message_class', 'IPM.Note.SMIME.MultipartSigned');
-					} else {
-						record.set('message_class', 'IPM.Note');
-					}
-
-					button.setIconClass('icon_smime_encrypt');
-					// Reset smime property
-					record.set('smime','');
-					// Reset send action, otherwise the saveRecord will trigger a send when the user deselects encryption
-					record.actions = {};
-
-					// Remove event
-					dialog.un('beforesendrecord', this.onBeforeSendRecord ,this);
-					break;
+			// Add event to check if all recipients have a public key
+			dialog.on('beforesendrecord', this.onBeforeSendRecord ,this);
+			break;
+		// Unselecting encrypt functionality
+		case 'IPM.Note.deferSMIME':
+		case 'IPM.Note.deferSMIME.SignedEncrypt':
+			if (record.get('message_class') === 'IPM.Note.deferSMIME.SignedEncrypt') {
+				record.set('message_class', 'IPM.Note.deferSMIME.MultipartSigned');
+			} else {
+				record.set('message_class', 'IPM.Note');
 			}
-			dialog.saveRecord();
+
+			button.setIconClass('icon_smime_encrypt');
+			// Reset smime property
+			record.set('smime','');
+			// Reset send action, otherwise the saveRecord will trigger a send when the user deselects encryption
+			record.actions = {};
+
+			// Remove event
+			dialog.un('beforesendrecord', this.onBeforeSendRecord ,this);
+			break;
 		}
+		dialog.saveRecord();
 	},
 
 	/**
@@ -2114,41 +2114,43 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 	{
 		var dialog = this.getRespectiveDialog(button);
 		var record = dialog.record;
-		if(record) {
-			var plugin = this;
-			var user = container.getUser();
-			var request = function() {
-				container.getRequest().singleRequest(
-					'pluginsmimemodule',
-					'certificate',
-					{
-						'user' : user.getSMTPAddress()
-					},
-					new Zarafa.plugins.smime.data.SmimeResponseHandler({
-						successCallback : plugin.onCertificateCallback.createDelegate(button)
-					})
-				);
-			};
-			switch(record.get('message_class')) {
-				// We want to sign
-				case 'IPM.Note':
-					button.message_class = 'IPM.Note.SMIME.MultipartSigned';
-					request();
-					break;
-				// Encrypt + Sign
-				case 'IPM.Note.SMIME':
-					button.message_class = 'IPM.Note.SMIME.SignedEncrypt';
-					request();
-					break;
-				case 'IPM.Note.SMIME.MultipartSigned':
-					button.setIconClass('icon_smime_sign');
-					record.set('message_class', 'IPM.Note');
-					break;
-				case 'IPM.Note.SMIME.SignedEncrypt':
-					button.setIconClass('icon_smime_sign');
-					record.set('message_class', 'IPM.Note.SMIME');
-					break;
-			}
+		if (!record) {
+			dialog.saveRecord();
+			return;
+		}
+		var plugin = this;
+		var user = container.getUser();
+		var request = function() {
+			container.getRequest().singleRequest(
+				'pluginsmimemodule',
+				'certificate',
+				{
+					'user' : user.getSMTPAddress()
+				},
+				new Zarafa.plugins.smime.data.SmimeResponseHandler({
+					successCallback : plugin.onCertificateCallback.createDelegate(button)
+				})
+			);
+		};
+		switch (record.get('message_class')) {
+		// We want to sign
+		case 'IPM.Note':
+			button.message_class = 'IPM.Note.deferSMIME.MultipartSigned';
+			request();
+			break;
+		// Encrypt + Sign
+		case 'IPM.Note.deferSMIME':
+			button.message_class = 'IPM.Note.deferSMIME.SignedEncrypt';
+			request();
+			break;
+		case 'IPM.Note.deferSMIME.MultipartSigned':
+			button.setIconClass('icon_smime_sign');
+			record.set('message_class', 'IPM.Note');
+			break;
+		case 'IPM.Note.deferSMIME.SignedEncrypt':
+			button.setIconClass('icon_smime_sign');
+			record.set('message_class', 'IPM.Note.deferSMIME');
+			break;
 		}
 		dialog.saveRecord();
 	},
@@ -2180,12 +2182,12 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 		var bid = -1;
 
 		switch(type) {
-			case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.passphrasewindow']:
-				bid = 1;
-				break;
-			case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.changepassphrasecontentpanel']:
-				bid = 1;
-				break;
+		case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.passphrasewindow']:
+			bid = 1;
+			break;
+		case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.changepassphrasecontentpanel']:
+			bid = 1;
+			break;
 		}
 		return bid;
 	},
@@ -2200,12 +2202,12 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 		var component;
 
 		switch(type) {
-			case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.passphrasewindow']:
-				component = Zarafa.plugins.smime.dialogs.PassphraseContentPanel;
-				break;
-			case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.changepassphrasecontentpanel']:
-				component = Zarafa.plugins.smime.dialogs.ChangePassphraseContentPanel;
-				break;
+		case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.passphrasewindow']:
+			component = Zarafa.plugins.smime.dialogs.PassphraseContentPanel;
+			break;
+		case Zarafa.core.data.SharedComponentType['plugin.smime.dialog.changepassphrasecontentpanel']:
+			component = Zarafa.plugins.smime.dialogs.ChangePassphraseContentPanel;
+			break;
 		}
 
 		return component;
@@ -2224,9 +2226,13 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 			sortable : false,
 			renderer :  function(value, p, record) {
 				var messageClass = record.get('message_class');
-				if(messageClass == 'IPM.Note.SMIME' || messageClass == 'IPM.Note.SMIME.SignedEncrypt') {
+				if (messageClass == 'IPM.Note.SMIME' ||
+				    messageClass == 'IPM.Note.deferSMIME' ||
+				    messageClass == 'IPM.Note.SMIME.SignedEncrypt' ||
+				    messageClass == 'IPM.Note.deferSMIME.SignedEncrypt') {
 					p.css = 'icon_smime_encrypt';
-				} else if(messageClass == 'IPM.Note.SMIME.MultipartSigned') {
+				} else if (messageClass == 'IPM.Note.SMIME.MultipartSigned' ||
+				    messageClass == 'IPM.Note.deferSMIME.MultipartSigned') {
 					p.css = 'icon_smime_sign';
 				}
 				return '';
@@ -2247,9 +2253,13 @@ Zarafa.plugins.smime.SmimePlugin = Ext.extend(Zarafa.core.Plugin, {
 	showMessageClass : function(insertionPoint, record) {
 		var messageClass = record.get('message_class');
 		var icon = "";
-		if (messageClass == 'IPM.Note.SMIME' || messageClass == 'IPM.Note.SMIME.SignedEncrypt') {
+		if (messageClass == 'IPM.Note.SMIME' ||
+		    messageClass == 'IPM.Note.deferSMIME' ||
+		    messageClass == 'IPM.Note.SMIME.SignedEncrypt' ||
+		    messageClass == 'IPM.Note.deferSMIME.SignedEncrypt') {
 			icon = 'icon_smime_encrypt';
-		} else if (messageClass == 'IPM.Note.SMIME.MultipartSigned') {
+		} else if (messageClass == 'IPM.Note.SMIME.MultipartSigned' ||
+		    messageClass == 'IPM.Note.deferSMIME.MultipartSigned') {
 			icon = 'icon_smime_sign';
 		}
 
@@ -2331,39 +2341,38 @@ Zarafa.plugins.smime.SmimeText = function () {
 		 */
 		getPopupText: function (index) {
 			switch (index) {
-				// Verified successfully
-				case 0:
-					return _('grommunio Web can verify digital signatures of emails. A successful verification reassures you ') +
-						_('that the message has not been tampered with and validates the identity of the sender.') + "<br><br>" +
-						_('The verification of the digital signature was successful for this email message.');
-				// Could not verify, missing public certificate
-				case 1:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('grommunio Web could not find a public certificate for the recipient.'));
-				// Signature verified, but certificate expired
-				case 2:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The identity of the sender and authenticity of the message content have been verified, but the certificate used to sign the message expired on [d-m-Y].'));
-				// Signature could not be verified
-				case 3:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The digital signature could not be verified for unknown reasons.'));
-				// Signature has been revoked
-				case 4:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The digital certificate used to sign this message has been revoked (i.e. the sender has marked it as compromised)'));
-				// The verification step with the Certificate Authority failed
-				case 5:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The verification service of the certificate authority that signed the sender\'s certificate is not available. The validity of the certificate could not be verified.'));
-				// Certificate does not support OCSP
-				case 9:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The revocation status of the digital certificate used to sign this email is unknown (Server is unavailable or certificate does not support OCSP). The validity of the certificate could not be verified.'));
-				// OCSP check disabled
-				case 10:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The revocation status of the digital certificate used to sign this email is disabled (OCSP). The validity of the certificate could not be verified.'));
-				// OCSP server offline
-				case 11:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('The certificate verification server (OCSP) is temporarily offline.'));
-				// User
-				case 13:
-					return Zarafa.plugins.smime.SmimeText.createMessage(_('Sender is removed from the server.'));
-
+			// Verified successfully
+			case 0:
+				return _('grommunio Web can verify digital signatures of emails. A successful verification reassures you ') +
+					_('that the message has not been tampered with and validates the identity of the sender.') + "<br><br>" +
+					_('The verification of the digital signature was successful for this email message.');
+			// Could not verify, missing public certificate
+			case 1:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('grommunio Web could not find a public certificate for the recipient.'));
+			// Signature verified, but certificate expired
+			case 2:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The identity of the sender and authenticity of the message content have been verified, but the certificate used to sign the message expired on [d-m-Y].'));
+			// Signature could not be verified
+			case 3:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The digital signature could not be verified for unknown reasons.'));
+			// Signature has been revoked
+			case 4:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The digital certificate used to sign this message has been revoked (i.e. the sender has marked it as compromised)'));
+			// The verification step with the Certificate Authority failed
+			case 5:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The verification service of the certificate authority that signed the sender\'s certificate is not available. The validity of the certificate could not be verified.'));
+			// Certificate does not support OCSP
+			case 9:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The revocation status of the digital certificate used to sign this email is unknown (Server is unavailable or certificate does not support OCSP). The validity of the certificate could not be verified.'));
+			// OCSP check disabled
+			case 10:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The revocation status of the digital certificate used to sign this email is disabled (OCSP). The validity of the certificate could not be verified.'));
+			// OCSP server offline
+			case 11:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('The certificate verification server (OCSP) is temporarily offline.'));
+			// User
+			case 13:
+				return Zarafa.plugins.smime.SmimeText.createMessage(_('Sender is removed from the server.'));
 			}
 		},
 
@@ -2376,34 +2385,34 @@ Zarafa.plugins.smime.SmimeText = function () {
 		 */
 		getMessageInfo: function (index) {
 			switch (index) {
-				case 0:
-					return _('Signature verified successfully');
-				case 1:
-					return _('Could not verify signature, missing public certificate');
-				case 2:
-					return _('Signature verification successful, but certificate is expired');
-				case 3:
-					return _('Signature could not be verified');
-				case 4:
-					return _('Certificate has been revoked');
-				case 5:
-					return _('Verification with Certificate Authority failed');
-				case 6:
-					return _('Message decrypted succesfully');
-				case 7:
-					return _('Message decryption failed');
-				case 8:
-					return _('Please') + '<b> ' + _('click here') + ' </b> ' + _('to unlock your certificate');
-				case 9:
-					return _('Cannot determine revocation status of certificate');
-				case 10:
-					return _('Signature verified (OCSP disabled)');
-				case 11:
-					return _('Cannot determine revocation status of certificate');
-				case 12:
-					return _('Unable to decrypt this message. Certificate does not match');
-				case 13:
-					return _('Verification failed. User is removed from the server.');
+			case 0:
+				return _('Signature verified successfully');
+			case 1:
+				return _('Could not verify signature, missing public certificate');
+			case 2:
+				return _('Signature verification successful, but certificate is expired');
+			case 3:
+				return _('Signature could not be verified');
+			case 4:
+				return _('Certificate has been revoked');
+			case 5:
+				return _('Verification with Certificate Authority failed');
+			case 6:
+				return _('Message decrypted succesfully');
+			case 7:
+				return _('Message decryption failed');
+			case 8:
+				return _('Please') + '<b> ' + _('click here') + ' </b> ' + _('to unlock your certificate');
+			case 9:
+				return _('Cannot determine revocation status of certificate');
+			case 10:
+				return _('Signature verified');
+			case 11:
+				return _('Cannot determine revocation status of certificate');
+			case 12:
+				return _('Unable to decrypt this message. Certificate does not match');
+			case 13:
+				return _('Verification failed. User is removed from the server.');
 			}
 		},
 
@@ -2415,14 +2424,14 @@ Zarafa.plugins.smime.SmimeText = function () {
 		 */
 		getStatusMessageClass: function (index) {
 			switch (index) {
-				case 0:
-					return 'smime-info-good';
-				case 1:
-					return 'smime-info-partial';
-				case 2:
-					return 'smime-info-fatal';
-				case 3:
-					return 'smime-info-info';
+			case 0:
+				return 'smime-info-good';
+			case 1:
+				return 'smime-info-partial';
+			case 2:
+				return 'smime-info-fatal';
+			case 3:
+				return 'smime-info-info';
 			}
 		},
 
@@ -2434,12 +2443,12 @@ Zarafa.plugins.smime.SmimeText = function () {
 		 */
 		getPopupStatus: function (index) {
 			switch (index) {
-				case 0:
-					return '';
-				case 1:
-					return 'warning';
-				case 2:
-					return 'error';
+			case 0:
+				return '';
+			case 1:
+				return 'warning';
+			case 2:
+				return 'error';
 			}
 		}
 	};
