@@ -376,30 +376,31 @@
 
 			// Compare the timezone definitions of the client and the appointment.
 			// Further processing is only required if they don't match.
-			if (!$GLOBALS['entryid']->compareEntryIds($this->tzdef, $calendaritem['props']['tzdefstart'])) {
-				if ($this->tzdefObj === false) {
-					$this->tzdefObj = $GLOBALS['entryid']->createTimezoneDefinitionObject($this->tzdef);
-				}
-				$this->tzEffRuleIdx = getEffectiveTzreg($this->tzdefObj['rules']);
+			if ($GLOBALS['entryid']->compareEntryIds($this->tzdef, $calendaritem['props']['tzdefstart']))
+				return;
 
-				$appTzDefStart = $GLOBALS['entryid']->createTimezoneDefinitionObject(hex2bin($calendaritem['props']['tzdefstart']));
-
-				// Find TZRULE_FLAG_EFFECTIVE_TZREG rule for the appointment's timezone
-				$appTzEffRuleIdx = getEffectiveTzreg($appTzDefStart['rules']);
-
-				if (!is_null($this->tzEffRuleIdx) && !is_null($appTzEffRuleIdx)) {
-					// first apply the bias of the appointment timezone and the bias of the browser
-					$localStart = $calendaritem['props']['startdate'] - $appTzDefStart['rules'][$appTzEffRuleIdx]['bias'] * 60 + $this->tzdefObj['rules'][$this->tzEffRuleIdx]['bias'] * 60;
-					if (isDst($appTzDefStart['rules'][$appTzEffRuleIdx], $calendaritem['props']['startdate'])) {
-						$localStart -= $appTzDefStart['rules'][$appTzEffRuleIdx]['dstbias'] * 60;
-					}
-					if (isDst($this->tzdefObj['rules'][$this->tzEffRuleIdx], $calendaritem['props']['startdate'])) {
-						$localStart += $this->tzdefObj['rules'][$this->tzEffRuleIdx]['dstbias'] * 60;
-					}
-					$duration = $calendaritem['props']['duedate'] - $calendaritem['props']['startdate'];
-					$calendaritem['props']['startdate'] = $calendaritem['props']['commonstart'] = $localStart;
-					$calendaritem['props']['duedate'] = $calendaritem['props']['commonend'] = $localStart + $duration;
-				}
+			if ($this->tzdefObj === false) {
+				$this->tzdefObj = $GLOBALS['entryid']->createTimezoneDefinitionObject($this->tzdef);
 			}
+			$this->tzEffRuleIdx = getEffectiveTzreg($this->tzdefObj['rules']);
+
+			$appTzDefStart = $GLOBALS['entryid']->createTimezoneDefinitionObject(hex2bin($calendaritem['props']['tzdefstart']));
+
+			// Find TZRULE_FLAG_EFFECTIVE_TZREG rule for the appointment's timezone
+			$appTzEffRuleIdx = getEffectiveTzreg($appTzDefStart['rules']);
+
+			if (is_null($this->tzEffRuleIdx) && !is_null($appTzEffRuleIdx))
+				return;
+			// first apply the bias of the appointment timezone and the bias of the browser
+			$localStart = $calendaritem['props']['startdate'] - $appTzDefStart['rules'][$appTzEffRuleIdx]['bias'] * 60 + $this->tzdefObj['rules'][$this->tzEffRuleIdx]['bias'] * 60;
+			if (isDst($appTzDefStart['rules'][$appTzEffRuleIdx], $calendaritem['props']['startdate'])) {
+				$localStart -= $appTzDefStart['rules'][$appTzEffRuleIdx]['dstbias'] * 60;
+			}
+			if (isDst($this->tzdefObj['rules'][$this->tzEffRuleIdx], $calendaritem['props']['startdate'])) {
+				$localStart += $this->tzdefObj['rules'][$this->tzEffRuleIdx]['dstbias'] * 60;
+			}
+			$duration = $calendaritem['props']['duedate'] - $calendaritem['props']['startdate'];
+			$calendaritem['props']['startdate'] = $calendaritem['props']['commonstart'] = $localStart;
+			$calendaritem['props']['duedate'] = $calendaritem['props']['commonend'] = $localStart + $duration;
 		}
 	}
